import { JuspayEnvironment } from '../JuspayEnvironment.js';
import JuspayResource from '../JuspayResource.js';
import { PaymentCreateRequest, JuspayConfig, HttpResponse } from '../types/index.js';
export default class Payments extends JuspayResource {
    constructor(juspayEnvironment: JuspayEnvironment);
    /**
     * initiate payment for the order id, for merchants
     * @param body order_id
     * @param juspayConfig override config using this params usage:- {apiKey: '', merchantId: '', ...}
     * @returns Promise Response Object
     *
     * @note
     * If you are a PCI compliant merchant, you can combine Create Order API request with Payments API request in a single API request.
     * Add order details as below:-
     * @example 'order.order_id', 'order.amount'
     *
     * @link
     * - card:- https://docs.juspay.in/api-reference/docs/express-checkout/credit--debit-card-transaction
     * - netbanking:- https://docs.juspay.in/api-reference/docs/express-checkout/netbanking-payment
     * - wallet:- https://docs.juspay.in/api-reference/docs/express-checkout/wallet-payment
     * - wallet direct debit:- https://docs.juspay.in/api-reference/docs/express-checkout/wallet-direct-debit
     * - upi collect:- https://docs.juspay.in/api-reference/docs/express-checkout/upi-collect-payment
     * - upi intent:- https://docs.juspay.in/api-reference/docs/express-checkout/upi-intent-payment
     * - consumer finance:- https://docs.juspay.in/api-reference/docs/express-checkout/consumer-finance-payment
     */
    create(body: PaymentCreateRequest, juspayConfig?: JuspayConfig): Promise<HttpResponse>;
}
