import { RequestEntity } from './Http.js';
export interface CreateCustomerRequest extends RequestEntity {
    /**
     * Unique ID that you use to represent the customer in your database. This must be atleast 8 characters and must be unique. The typical value for this field would be email address or mobile number or auto increment ID that you have in your DB.
     */
    object_reference_id: string;
    /**
     * Customer’s mobile number. We recommend passing only the 10 digit number without appending "+" or mobile country code.
     */
    mobile_number: string;
    /**
     * Customer’s e-mail address.
     */
    email_address?: string;
    /**
     * Customer's first name.
     */
    first_name?: string;
    /**
     * Customer's last name.
     */
    last_name?: string;
    /**
     * Mobile country code. No need to prefix “+”.
     */
    mobile_country_code?: string;
    /**
     * get_client_auth_token
     */
    'options.get_client_auth_token'?: string;
}
export interface UpdateCustomerRequest extends RequestEntity {
    /**
     * Customer’s mobile number. We recommend passing only the 10 digit number without appending "+" or mobile country code.
     */
    mobile_number?: string;
    /**
     * Customer’s e-mail address.
     */
    email_address?: string;
    /**
     * Customer's first name.
     */
    first_name?: string;
    /**
     * Customer's last name.
     */
    last_name?: string;
    /**
     * Mobile country code. No need to prefix “+”.
     */
    mobile_country_code?: string;
}
export interface GetCustomerQuery extends RequestEntity {
    /**
     * get_client_auth_token
     */
    'options.get_client_auth_token'?: string;
}
