import { RequestHeaders } from './Http.js';
/**
 * Juspay's Config
 */
export interface JuspayConfig {
    /**
     * API key's are given during account creation with juspay
     */
    apiKey?: string;
    /**
     * merchant id given to juspay
     */
    merchantId?: string;
    /**
     * either sandbox for testing or production
     * @default
     * 'https://sandbox.juspay.in'
     */
    baseUrl?: string;
    /**
     * default timeout for all the api's
     * note that 0 is not a valid input and will be replaced by default value
     * @default 80_000
     */
    timeout?: number;
    /**
     * sdk version
     * @default '2019-05-07'
     */
    version?: string;
    /**
     * default headers for all apis
     */
    headers?: RequestHeaders;
    /**
     * encryption config for JWE JWS encryption
     * to setup keys in expresscheckout dashboard
     * go to JWT encryption key
     */
    jweAuth?: JweAuth;
}
export interface JweAuth {
    /**
     * public key generated by juspay
     */
    publicKey: string;
    /**
     * private key generated by merchant, whose public key is uploaded to juspay via dashboard
     */
    privateKey: string;
    /**
     * key id extracted from dashboard
     */
    keyId: string;
}
