import { RequestEntity } from './Http.js';
export interface CreateSessionRequest extends RequestEntity {
    /**
     * Unique Identifier for the order. Should be Alphanumeric with character length less than 18.
     */
    order_id: string;
    /**
     * Amount that the customer has to pay. Will accept stringified double or integer values with upto two decimal places. For example, "100.15" and "100" are valid input but "100.1532" is not valid.
     */
    amount: number;
    /**
     * - It is the ID with which merchant refers to a customer object. This id is used to access the stored payment methods, allow EMI transactions and setup subscriptions.
     * - In case of guest login it should be an empty string.
     */
    customer_id?: string;
    /**
     * Email address of the customer. If the backend gateway requires it, then you must send this value.
     */
    customer_email?: string;
    /**
     * Mobile number or fixed line number of the customer. If the backend gateway requires it, then you must send this value. We recommend passing a 10-digit number without including the "+91" or any mobile country code at the beginning.
     */
    customer_phone?: string;
    /**
     * A unique identifier of merchant. This is available in welcome e-mail shared by Juspay
     */
    payment_page_client_id?: string;
    /**
     * Value "paymentPage" is to start the payment page interface.
     */
    action?: string;
    /**
     * Value "paymentPage" is to start the payment page interface.
     */
    return_url?: string;
    /**
     * Value "paymentPage" is to start the payment page interface.
     */
    first_name?: string;
    /**
     * Value "paymentPage" is to start the payment page interface.
     */
    last_name?: string;
    /**
     * To use multiple MID setup, please pass reference Id as per the following format:
     * -Assume you have two lines of businesses BUS and TRAIN; and BUS transactions should be processed via RAZORPAY and TRAIN transactions via PAYU.
     * -Configure RAZORPAY with Gateway Reference ID as BUS and PAYU with Gateway Reference ID as TRAIN in the dashboard.
     * -For BUS transcations, pass the following parameter in Session API. metadata.JUSPAY:gateway_reference_id : BUS
     * -For TRAIN transcations, pass the following parameter in Session API. metadata.JUSPAY:gateway_reference_id : TRAI
     */
    'metadata.JUSPAY:gateway_reference_id'?: 'REQUIRED' | 'OPTIONAL' | string;
    /**
     * Defines what kind mandate support is available during a session. Required to create a Mandate. Chose between the follow values based upon requirements :-
     * -REQUIRED : Mandate is must for completing transaction. Only instruments which support Mandate will be shown
     * -OPTIONAL : Mandate is a user choice for completing transaction.
     */
    'options.create_mandate'?: string;
    /**
     * Amount that can be set as maximum mandate Mandatory only if mandate.amount_rule = VARIABLE </p
     */
    'options.max_amount'?: string;
    /**
     * Mandate start date in UNIX EPOCH timestamp (UTC timezone). The start date has to be today's date</p
     */
    'options.start_date'?: string;
    /**
     * Mandate end date in UNIX EPOCH timestamp (UTC timezone), from when a mandate will move to EXPIRED state and recurring mandate will not be allowed </p
     */
    'options.end_date'?: string;
    /**
     * Defines the frequency of mandate execution, how often a customer should be charged
     * @example ONETIME DAILY WEEKLY FORTNIGHTLY MONTHLY BIMONTHLY QUARTERLY HALFYEARLY YEARLY ASPRESENTED
     */
    'options.frequency'?: string;
    /**
     * 1-7 when frequency is WEEKLY. In weekly, serial numbers start from Monday. Monday represents 1 and Sunday represents 7.
     * 1-16 when frequency is FORTNIGHTLY. This mandate is executed twice a month. First day of the month is represented by value '1' and ends with '15' on 15th day of the month. Then again starts with '1' for 16th of the month and ends with the last day of the month.
     * 1-31 when frequency is MONTHLY, BIMONTHLY, QUARTERLY, HALFYEARLY, or YEARLY.
     * Not required when frequency is ONETIME, DAILY, ASPRESENTED. For Razorpay, rule_value will be considered as the last date of the week/month/year. For Paytm, rule_value will be considered as today's date/day
     */
    'options.rule_value'?: string;
    /**
     * In case of FIXED amount_rule, amount will be equal to max amount
     */
    'options.amount_rule'?: string;
    /**
     * If false, the mandate cannot be revoked by the customer once set. It should be true for Recurring and true/false for ONETIME
     */
    'options.revokable_by_customer'?: boolean;
    /**
     * Should be true for ONETIME and false for Recurring.
     */
    'options.block_funds'?: boolean;
    udf1?: string;
    udf2?: string;
    udf3?: string;
    udf4?: string;
    udf5?: string;
    udf6?: string;
    udf7?: string;
    udf8?: string;
    udf9?: string;
    udf10?: string;
}
